pub struct InlineCompletionTriggerKind(/* private fields */);Expand description
Describes how an [InlineCompletionItemProvider] was triggered.
@since 3.18.0
Implementations
Sourceimpl InlineCompletionTriggerKind
impl InlineCompletionTriggerKind
Sourcepub const INVOKED: InlineCompletionTriggerKind
pub const INVOKED: InlineCompletionTriggerKind
Completion was triggered explicitly by a user gesture. Return multiple completion items to enable cycling through them.
Sourcepub const AUTOMATIC: InlineCompletionTriggerKind
pub const AUTOMATIC: InlineCompletionTriggerKind
Completion was triggered automatically while editing. It is sufficient to return a single completion item in this case.